@@ -1,4 +1,4 @@
 # you can place your validation functions in there.
 
-def myvalidationfunc(kwargs)
+def myvalidationfunc(kwargs):
     return kwargs.get('url', '').startwith('http://localhost')
